"""This module contains the AnalysisStatusResponse domain model."""

from .analysis import AnalysisShort


class AnalysisStatusResponse(AnalysisShort):
    """The API response domain model for the status of a single analysis."""

    pass
